import React from 'react';
import { Meta } from '@storybook/react';
import { Provider } from 'react-redux';
import { configureStore } from '@reduxjs/toolkit';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, visualizationSlice } from '../../../data-access/store';
import { MapComponent } from './mapvis';
import { mockData } from '../../../mock-data/query-result/mockData';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof MapComponent.component> = {
  title: 'Visualizations/MapVis',
  component: MapComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const DutchVehicleTheft = {
  args: {
    ...(await mockData.mockMobilityQueryResult()),
    settings: {
      layer: 'node',
      lat: 'lat',
      lon: 'long',
      node: 'parkings',
    },
  },
};

export const AmericanFlights = {
  args: {
    ...(await mockData.bigMockQueryResults()),
    settings: {
      layer: 'node',
      lat: 'lat',
      lon: 'long',
      node: 'airports',
    },
  },
};

export default Component;
